Index: doc/options.txt
===================================================================
--- doc/options.txt	(revision 4701)
+++ doc/options.txt	(working copy)
@@ -457,6 +457,14 @@
 Increases paint speed at low zoom levels.
 Default is enabled, use --no-merge-lines to disable.
 
+;--allow-reverse-merge=detect|no|yes
+: 	Use this option to allow the reversing of lines and roads to get even better
+results from line merging. The default is detect, which means reversing is
+only enabled when the line rules contain at least one rule that sets the special
+tag mkgmap:has-direction=true. The value no means that the reversing is not
+allowed even if there is such a rule in lines. The value yes means that
+reversing is enabled.
+
 ;--min-size-polygon=NUM
 :   Removes all polygons smaller than NUM from the map.
 This reduces map size and speeds up redrawing of maps.
Index: src/uk/me/parabola/mkgmap/osmstyle/StyledConverter.java
===================================================================
--- src/uk/me/parabola/mkgmap/osmstyle/StyledConverter.java	(revision 4704)
+++ src/uk/me/parabola/mkgmap/osmstyle/StyledConverter.java	(working copy)
@@ -158,7 +158,7 @@
 	private int reportDeadEnds; 
 	private final boolean linkPOIsToWays;
 	private final boolean mergeRoads;
-	private final boolean forceReverseMerge;
+	private final boolean allowReverseMerge;
 	private final boolean routable;
 	private boolean forceEndNodesRoutingNodes; 
 	private final Tags styleOptionTags;
@@ -232,7 +232,21 @@
 		
 		// undocumented option - usually used for debugging only
 		mergeRoads = !props.getProperty("no-mergeroads", false);
-		forceReverseMerge = props.getProperty("force-reverse-merge", false);
+		
+		String allowReverseMergeOpt = props.getProperty("allow-reverse-merge", "detect");
+		switch (allowReverseMergeOpt) {
+		case "detect":
+			allowReverseMerge = styleSetsDirection;
+			break;
+		case "yes":
+			allowReverseMerge = true;
+			break;
+		case "no":
+			allowReverseMerge = false;
+			break;
+		default:
+			throw new ExitException("invalid parameter for option allow-reverse-merge:" + allowReverseMergeOpt);
+		}
 		routable = props.containsKey("route");
 		String styleOption= props.getProperty("style-option",null);
 		styleOptionTags = parseStyleOption(styleOption);
@@ -891,19 +905,20 @@
 	 */
 	private void mergeRoads() {
 		if (mergeRoads) {
-			// transfer any hasDirection flag to all lines concerning the same way
-			Set<Long> waysWithDirection = new HashSet<>();
-			if (styleSetsDirection) {
-				for (List<ConvertedWay> list : Arrays.asList(lines, roads)) {
-					list.stream().filter(cw -> cw.hasDirection() && cw.isValid())
-					.forEach(cw -> waysWithDirection.add(cw.getWay().getId()));
+			if (allowReverseMerge) {
+				// transfer any hasDirection flag to all lines concerning the same way
+				Set<Long> waysWithDirection = new HashSet<>();
+				if (styleSetsDirection) {
+					for (List<ConvertedWay> list : Arrays.asList(lines, roads)) {
+						list.stream().filter(cw -> cw.hasDirection() && cw.isValid())
+								.forEach(cw -> waysWithDirection.add(cw.getWay().getId()));
+					}
 				}
+				// set direction flag for roads which have overlay lines with direction
+				roads.stream().filter(cw -> waysWithDirection.contains(cw.getWay().getId()))
+						.forEach(cw -> cw.setHasDirection(true));
 			}
-			// set direction flag for roads which have overlay lines with direction
-			roads.stream().filter(cw -> waysWithDirection.contains(cw.getWay().getId()))
-					.forEach(cw -> cw.setHasDirection(true));
-					
-			RoadMerger merger = new RoadMerger(styleSetsDirection || forceReverseMerge);
+			RoadMerger merger = new RoadMerger(allowReverseMerge);
 			roads = merger.merge(roads, restrictions);
 		} else {
 			log.info("Merging roads is disabled");
